package com.datacloudsec.scan.tasks.scheduler.job.task;

import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.dao.BlineBugMapper;
import com.datacloudsec.scan.dao.BlineevalMapper;
import com.datacloudsec.scan.dao.ConfigMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.TaskBaseMapper;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.service.IBaseline;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.service.impl.BaselineService;
import com.datacloudsec.scan.service.impl.EngineService;
import com.datacloudsec.scan.service.impl.ReportService;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.SysLogJob;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.KafkaUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_tasks_scheduler_job_task.jar:com/datacloudsec/scan/tasks/scheduler/job/task/BlineTask.class */
public class BlineTask {
    private static final Logger LOG = Logger.getLogger(BlineTask.class);
    private static IBaseline baselineService = (IBaseline) InstanceUtil.newServiceInstance(BaselineService.class);
    private static TaskBaseMapper taskBaseMapper = (TaskBaseMapper) InstanceUtil.newDaoInstance(TaskBaseMapper.class);
    private static IReport reportService = (IReport) InstanceUtil.newServiceInstance(ReportService.class);
    private static AlarmlogMapper alarmlogMapper = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);
    private static ConfigMapper configMapper = (ConfigMapper) InstanceUtil.newDaoInstance(ConfigMapper.class);
    private static IEngine engine = new EngineService();
    private static final int BLINE_VULS_LIMIT = 200;
    private static final int BLINE_ERRS_LIMIT = 100;

    public static void blineScanSync(Map<String, Object> device) {
        if (device == null) {
            return;
        }
        SqlSession session = null;
        try {
            try {
                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                int offset1 = ObjectUtil.getInt(device.get("offset1")).intValue();
                int offset2 = ObjectUtil.getInt(device.get("offset2")).intValue();
                Map<String, Object> result = engine.blineGetResult(ObjectUtil.getInt(device.get("type"), -1), ObjectUtil.getString(device.get("engineId"), (String) null), ObjectUtil.getInt(device.get("localEid"), 0), offset1, BLINE_VULS_LIMIT, offset2, BLINE_ERRS_LIMIT);
                Task task = taskBaseMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                String error = ObjectUtil.getString(result.get("error"), (String) null);
                List<Map<String, Object>> vulstemp = (List) result.get("results");
                List<String> errs = (List) result.get("errs");
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                EngineMapper engMapper = (EngineMapper) session.getMapper(EngineMapper.class);
                BlineBugMapper blineBugMapper = (BlineBugMapper) session.getMapper(BlineBugMapper.class);
                BlineevalMapper blineevalMapper = (BlineevalMapper) session.getMapper(BlineevalMapper.class);
                double progress = ObjectUtil.getDouble(result.get("progress"), 0.0d);
                List<Map<String, Object>> vuls = new ArrayList<>();
                Integer status = null;
                if (progress == 100.0d) {
                    status = 2;
                }
                if (StringUtils.isNotBlank(error)) {
                    status = 3;
                }
                Integer updateDevCount = Integer.valueOf(engMapper.updateScanInfo(deviceid, status, Double.valueOf(progress), (Integer) null, (Integer) null, error == null ? "" : error, Integer.valueOf(offset1 + (vuls == null ? 0 : vuls.size())), Integer.valueOf(offset2 + (errs == null ? 0 : errs.size())), (Integer) null, new Date(), false));
                Integer scanCount = Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0));
                String topic = configMapper.getValueByName("kafka_topic");
                String address = configMapper.getValueByName("kafka_address");
                if (updateDevCount != null && updateDevCount.intValue() > 0) {
                    if (vulstemp != null) {
                        for (Map<String, Object> vul : vulstemp) {
                            if (!StringUtils.isBlank(ObjectUtil.getString(vul.get("id"), (String) null))) {
                                vul.put("value", Integer.valueOf("是".equals(ObjectUtil.getString(vul.get("value"), "")) ? 0 : 1));
                                vul.put("type", device.get("btype"));
                                vuls.add(vul);
                                if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                                    try {
                                        Map<String, Object> policyMap = blineevalMapper.getBlineById(ObjectUtil.getString(vul.get("id"), ""), "1=1", task == null ? "默认" : task.getBtype());
                                        if (MapUtils.isNotEmpty(policyMap)) {
                                            Map<String, Object> data = new HashMap<>();
                                            data.put("bug_id", ObjectUtil.getString(policyMap.get("poliid"), ""));
                                            data.put("bug_name", ObjectUtil.getString(policyMap.get("name"), ""));
                                            data.put("bug_desct", ObjectUtil.getString(policyMap.get("desct"), ""));
                                            data.put("bug_ip", ObjectUtil.getString(device.get("ip"), ""));
                                            data.put("bug_type", ObjectUtil.getString(policyMap.get("name_cn"), ""));
                                            data.put("bug_level", ObjectUtil.getString(policyMap.get("level"), ""));
                                            data.put("bug_status", 1);
                                            KafkaUtil.getInstance().send(data);
                                        }
                                    } catch (Exception e) {
                                        LOG.error("kafka发送失败：", e);
                                    }
                                }
                            }
                        }
                        if (CollectionUtils.isNotEmpty(vuls)) {
                            if (scanCount.intValue() == 1) {
                                engMapper.blineReplaceVuls(deviceid, vuls);
                            } else {
                                engMapper.blineReplaceVuls2(deviceid, vuls);
                            }
                        }
                    }
                    if (errs != null && errs.size() > 0) {
                        engMapper.blineAddErrs(deviceid, errs);
                    }
                    if (progress == 100.0d) {
                        if (scanCount.intValue() > 1) {
                            List<Map<String, Object>> oldBugs = blineBugMapper.getBlineResByDevid(deviceid);
                            blineBugMapper.delResultByDevId(deviceid);
                            engMapper.blineCopyRes(deviceid);
                            blineBugMapper.delResultByDevId2(deviceid);
                            if (oldBugs != null && oldBugs.size() > 0) {
                                blineBugMapper.addBlineResult2(oldBugs, deviceid);
                            }
                        }
                        Map<String, Object> bline = blineBugMapper.bugCountByDev(deviceid);
                        Date time = new Date();
                        blineBugMapper.addBlineStatis(1, Integer.valueOf(ObjectUtil.getInt(bline.get("hy"), 0)), Integer.valueOf(ObjectUtil.getInt(bline.get("hn"), 0)), deviceid, time);
                        blineBugMapper.addBlineStatis(2, Integer.valueOf(ObjectUtil.getInt(bline.get("my"), 0)), Integer.valueOf(ObjectUtil.getInt(bline.get("mn"), 0)), deviceid, time);
                        blineBugMapper.addBlineStatis(3, Integer.valueOf(ObjectUtil.getInt(bline.get("ly"), 0)), Integer.valueOf(ObjectUtil.getInt(bline.get("ln"), 0)), deviceid, time);
                    }
                    if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                        try {
                            Map<String, Object> data2 = new HashMap<>();
                            data2.put("ip", ObjectUtil.getString(device.get("ip"), ""));
                            KafkaUtil.getInstance().send(data2);
                        } catch (Exception e2) {
                            LOG.error("kafka发送失败：", e2);
                        }
                    }
                }
                session.commit();
                if (status != null && (status.intValue() == 2 || status.intValue() == 3)) {
                    List<Map<String, Object>> queryBlineBug = alarmlogMapper.queryBlineBug(deviceid);
                    if (CollectionUtils.isNotEmpty(queryBlineBug)) {
                        alarmlogMapper.delAlarmlogByTime();
                        alarmlogMapper.batchInsert(queryBlineBug);
                    }
                    Map<String, Object> waitingDev = engMapper.getWaitingDev(2, deviceid);
                    if (waitingDev != null && waitingDev.size() > 0) {
                        baselineService.start(ObjectUtil.getInt(waitingDev.get("id")));
                    }
                    SysLogJob.addBugs(blineBugMapper.getBugsForLog(deviceid));
                    if (ObjectUtil.getInt(device.get("alarmType"), 0) == 1 || StringUtils.isNotBlank(ObjectUtil.getString(device.get("val2"), ""))) {
                        AlermJob.alermDevice(device);
                    }
                    FtpUtil.reportUpload(task, device, (String) IReport.REPORT_CHK.get("bline"), "bline");
                    if (StringUtils.isNotBlank(task.getVal3()) && "1".equals(task.getVal3())) {
                        String expname = String.valueOf(task.getName()) + "_" + ObjectUtil.getString(device.get("name"), "").replace(".", "-").replaceAll("[\\s\\\\/:\\*\\?\\\"<>\\|]", "");
                        reportService.export(ObjectUtil.getString(device.get("id"), ""), expname, "doc", (String) IReport.REPORT_CHK.get("bline"), "bline", (String) null, (String) null, (String) null, (String) null, (String) null, (String) null);
                    }
                }
                if (session != null) {
                    session.close();
                }
            } catch (Exception e3) {
                if (session != null) {
                    session.rollback();
                }
                LOG.error("", e3);
                if (session != null) {
                    session.close();
                }
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }
}
